@@ -13,7 +13,7 @@
 ;;; GNU General Public License for more details.
 
 ;;; You should have received a copy of the GNU General Public License
-;;; along with this program.  If not, see <http://www.gnu.org/licenses/>.
+;;; along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 (in-package :consfigurator)
 (named-readtables:in-readtable :consfigurator)
@@ -261,6 +261,16 @@ property instead of applying it."
               :unapply (get psym 'papply)
               :args args)))
 
+(define-function-property-combinator reapplied (propapp)
+  (:retprop :type (proptype (car propapp))
+            :lambda (proplambda (car propapp))
+            :desc (lambda-ignoring-args
+                    (strcat "Reapplied: " (propapp-desc propapp)))
+            :hostattrs (lambda-ignoring-args (propapp-attrs propapp))
+            :apply (lambda-ignoring-args
+                     (unapply-propapp propapp)
+                     (apply-propapp propapp))))
+
 (define-function-property-combinator desc (desc propapp)
   (:retprop :type (propapp-type propapp)
             :desc (lambda () desc)
