@@ -138,6 +138,9 @@
            #:add-change
            #:return-changes
            #:sh-script-to-single-line
+           #:posix-left-trim
+           #:posix-right-trim
+           #:posix-trim
 
            #:*consfigurator-debug-level*
            #:with-indented-inform
@@ -304,6 +307,7 @@
            #:hostdeploy-these
            #:hostdeploy-these*
            #:localsudo
+           #:localsudon
            #:localhd
            #:continue-deploy*
            #:evals
@@ -562,6 +566,7 @@
                     #:uses-local-cacher
                     #:get-mirrors
                     #:standard-sources.list
+                    #:additional-suites
                     #:additional-sources
                     #:cache-cleaned
                     #:trusts-key
